# Python
import os
import sys
import traceback
# Pycompss
from pycompss.api.task import task
from pycompss.api.parameter import FILE_IN, FILE_OUT
# Adapters commons pycompss
from biobb_adapters.pycompss.biobb_commons import task_config
# Wrapped Biobb
from biobb_io.api.pdb_cluster_zip import PdbClusterZip  # Importing class instead of module to avoid name collision

task_time_out = int(os.environ.get('TASK_TIME_OUT', 0))


@task(output_pdb_zip_path=FILE_OUT, 
      on_failure="IGNORE", time_out=task_time_out)
def _pdbclusterzip(output_pdb_zip_path,  properties, **kwargs):
    
    task_config.pop_pmi(os.environ)
    
    try:
        PdbClusterZip(output_pdb_zip_path=output_pdb_zip_path, properties=properties, **kwargs).launch()
    except Exception as e:
        traceback.print_exc()
        raise e
    finally:
        sys.stdout.flush()
        sys.stderr.flush()


def pdb_cluster_zip(output_pdb_zip_path, properties=None, **kwargs):

    if (output_pdb_zip_path is None or (os.path.exists(output_pdb_zip_path) and os.stat(output_pdb_zip_path).st_size > 0)) and \
       True:
        print("WARN: Task PdbClusterZip already executed.")
    else:
        _pdbclusterzip( output_pdb_zip_path,  properties, **kwargs)